@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  *  Copyright © 2000-2003 Marco Pesenti Gritti
  *  Copyright © 2003 Christian Persch
@@ -626,8 +627,7 @@ ephy_embed_persist_class_init (EphyEmbedPersistClass *klass)
 void
 ephy_embed_persist_cancel (EphyEmbedPersist *persist)
 {
-	EphyEmbedPersistClass *klass = EPHY_EMBED_PERSIST_GET_CLASS (persist);
-	klass->cancel (persist);
+	g_object_unref (persist);
 }
 
 /**
@@ -647,8 +647,9 @@ ephy_embed_persist_cancel (EphyEmbedPersist *persist)
 gboolean
 ephy_embed_persist_save (EphyEmbedPersist *persist)
 {
-	EphyEmbedPersistClass *klass = EPHY_EMBED_PERSIST_GET_CLASS (persist);
-	return klass->save (persist);
+	g_object_ref (persist);
+
+	return FALSE;
 }
 
 /**
@@ -672,6 +673,5 @@ ephy_embed_persist_save (EphyEmbedPersist *persist)
 char *
 ephy_embed_persist_to_string (EphyEmbedPersist *persist)
 {
-       EphyEmbedPersistClass *klass = EPHY_EMBED_PERSIST_GET_CLASS (persist);
-       return klass->to_string (persist);
+	return NULL;
 }
